@@ -2,9 +2,9 @@ import re
 import sys
 import time
 
-from streamlink.plugin import Plugin, PluginOptions
+from streamlink.plugin import Plugin, PluginArguments, PluginArgument
 from streamlink.plugin.api import http, validate
-from streamlink.stream import HDSStream, HLSStream, HTTPStream
+from streamlink.stream import DASHStream, HDSStream, HLSStream, HTTPStream
 from streamlink.stream.ffmpegmux import MuxedStream
 from streamlink.utils import update_scheme
 
@@ -15,13 +15,16 @@ class Pluzz(Plugin):
     PLAYER_GENERATOR_URL = 'https://sivideo.webservices.francetelevisions.fr/assets/staticmd5/getUrl?id=jquery.player.7.js'
     TOKEN_URL = 'http://hdfauthftv-a.akamaihd.net/esi/TA?url={0}'
 
-    _url_re = re.compile(r'https?://((?:www)\.france\.tv/.+\.html|www\.(ludo|zouzous)\.fr/heros/[\w-]+|(sport|france3-regions)\.francetvinfo\.fr/.+?/(tv/direct)?)')
+    _url_re = re.compile(
+        r'https?://((?:www)\.france\.tv/.+\.html|www\.(ludo|zouzous)\.fr/heros/[\w-]+|(sport|france3-regions)\.francetvinfo\.fr/.+?/(tv/direct)?)')
     _pluzz_video_id_re = re.compile(r'data-main-video="(?P<video_id>.+?)"')
     _jeunesse_video_id_re = re.compile(r'playlist: \[{.*?,"identity":"(?P<video_id>.+?)@(?P<catalogue>Ludo|Zouzous)"')
     _f3_regions_video_id_re = re.compile(r'"http://videos\.francetv\.fr/video/(?P<video_id>.+?)@Regions"')
     _sport_video_id_re = re.compile(r'data-video="(?P<video_id>.+?)"')
-    _player_re = re.compile(r'src="(?P<player>//staticftv-a\.akamaihd\.net/player/jquery\.player.+?-[0-9a-f]+?\.js)"></script>')
-    _swf_re = re.compile(r'//staticftv-a\.akamaihd\.net/player/bower_components/player_flash/dist/FranceTVNVPVFlashPlayer\.akamai-[0-9a-f]+\.swf')
+    _player_re = re.compile(
+        r'src="(?P<player>//staticftv-a\.akamaihd\.net/player/jquery\.player.+?-[0-9a-f]+?\.js)"></script>')
+    _swf_re = re.compile(
+        r'"(bower_components/player_flash/dist/FranceTVNVPVFlashPlayer\.akamai-[0-9a-f]+\.swf)"')
     _hds_pv_data_re = re.compile(r"~data=.+?!")
     _mp4_bitrate_re = re.compile(r'.*-(?P<bitrate>[0-9]+k)\.mp4')
 
@@ -78,9 +81,15 @@ class Pluzz(Plugin):
 
     _player_schema = validate.Schema({'result': validate.url()})
 
-    options = PluginOptions({
-        "mux_subtitles": False
-    })
+    arguments = PluginArguments(
+        PluginArgument(
+            "mux-subtitles",
+            action="store_true",
+            help="""
+        Automatically mux available subtitles in to the output stream.
+        """
+        )
+    )
 
     @classmethod
     def can_handle_url(cls, url):
@@ -113,7 +122,7 @@ class Pluzz(Plugin):
         res = http.get(player_url)
         match = self._swf_re.search(res.text)
         if match is not None:
-            swf_url = update_scheme(self.url, match.group(0))
+            swf_url = 'https://staticftv-a.akamaihd.net/player/' + match.group(1)
 
         res = http.get(self.API_URL.format(video_id))
         videos = http.json(res, schema=self._api_schema)
@@ -153,15 +162,21 @@ class Pluzz(Plugin):
                 expired = expired or True
                 continue
 
-            # TODO: add DASH streams once supported
-            if '.mpd' in video_url:
-                continue
-
-            if '.f4m' in video_url or 'france.tv' in self.url:
+            if ('.f4m' in video_url or
+                '.mpd' in video_url or
+                'france.tv' in self.url or
+                'sport.francetvinfo.fr' in self.url):
                 res = http.get(self.TOKEN_URL.format(video_url))
                 video_url = res.text
 
-            if '.f4m' in video_url and swf_url is not None:
+            if '.mpd' in video_url:
+                # Get redirect video URL
+                res = http.get(res.text)
+                video_url = res.url
+                for bitrate, stream in DASHStream.parse_manifest(self.session,
+                                                                 video_url).items():
+                    streams.append((bitrate, stream))
+            elif '.f4m' in video_url and swf_url is not None:
                 for bitrate, stream in HDSStream.parse_manifest(self.session,
                                                                 video_url,
                                                                 is_akamai=True,
