@@ -28,6 +28,7 @@ class DASHStreamWriter(SegmentedStreamWriter):
             return
 
         try:
+            headers = {}
             now = datetime.datetime.now(tz=utc)
             if segment.available_at > now:
                 time_to_wait = (segment.available_at - now).total_seconds()
@@ -35,9 +36,18 @@ class DASHStreamWriter(SegmentedStreamWriter):
                 log.debug("Waiting for segment: {fname} ({wait:.01f}s)".format(fname=fname, wait=time_to_wait))
                 sleep_until(segment.available_at)
 
+            if segment.range:
+                start, length = segment.range
+                if length:
+                    end = start + length - 1
+                else:
+                    end = ""
+                headers["Range"] = "bytes={0}-{1}".format(start, end)
+
             return self.session.http.get(segment.url,
                                          timeout=self.timeout,
-                                         exception=StreamError)
+                                         exception=StreamError,
+                                         headers=headers)
         except StreamError as err:
             log.error("Failed to open segment {0}: {1}", segment.url, err)
             return self.fetch(segment, retries - 1)
@@ -60,10 +70,10 @@ class DASHStreamWorker(SegmentedStreamWorker):
         self.period = self.stream.period
 
     @staticmethod
-    def get_representation(mpd, representation_id):
+    def get_representation(mpd, representation_id, mime_type):
         for aset in mpd.periods[0].adaptationSets:
             for rep in aset.representations:
-                if rep.id == representation_id:
+                if rep.id == representation_id and rep.mimeType == mime_type:
                     return rep
 
     def iter_segments(self):
@@ -71,7 +81,7 @@ class DASHStreamWorker(SegmentedStreamWorker):
         back_off_factor = 1
         while not self.closed:
             # find the representation by ID
-            representation = self.get_representation(self.mpd, self.reader.representation_id)
+            representation = self.get_representation(self.mpd, self.reader.representation_id, self.reader.mime_type)
             refresh_wait = max(self.mpd.minimumUpdatePeriod.total_seconds(),
                                self.mpd.periods[0].duration.total_seconds()) or 5
             with sleeper(refresh_wait * back_off_factor):
@@ -96,7 +106,7 @@ class DASHStreamWorker(SegmentedStreamWorker):
             return
 
         self.reader.buffer.wait_free()
-        log.debug("Reloading manifest ({0})".format(self.reader.representation_id))
+        log.debug("Reloading manifest ({0}:{1})".format(self.reader.representation_id, self.reader.mime_type))
         res = self.session.http.get(self.mpd.url, exception=StreamError)
 
         new_mpd = MPD(self.session.http.xml(res, ignore_ns=True),
@@ -104,7 +114,7 @@ class DASHStreamWorker(SegmentedStreamWorker):
                       url=self.mpd.url,
                       timelines=self.mpd.timelines)
 
-        new_rep = self.get_representation(new_mpd, self.reader.representation_id)
+        new_rep = self.get_representation(new_mpd, self.reader.representation_id, self.reader.mime_type)
         with freeze_timeline(new_mpd):
             changed = len(list(itertools.islice(new_rep.segments(), 1))) > 0
 
@@ -118,10 +128,11 @@ class DASHStreamReader(SegmentedStreamReader):
     __worker__ = DASHStreamWorker
     __writer__ = DASHStreamWriter
 
-    def __init__(self, stream, representation_id, *args, **kwargs):
+    def __init__(self, stream, representation_id, mime_type, *args, **kwargs):
         SegmentedStreamReader.__init__(self, stream, *args, **kwargs)
+        self.mime_type = mime_type
         self.representation_id = representation_id
-        log.debug("Opening DASH reader for: {0}".format(self.representation_id))
+        log.debug("Opening DASH reader for: {0} ({1})".format(self.representation_id, self.mime_type))
 
 
 
@@ -198,11 +209,11 @@ class DASHStream(Stream):
 
     def open(self):
         if self.video_representation:
-            video = DASHStreamReader(self, self.video_representation.id)
+            video = DASHStreamReader(self, self.video_representation.id, self.video_representation.mimeType)
             video.open()
 
         if self.audio_representation:
-            audio = DASHStreamReader(self, self.audio_representation.id)
+            audio = DASHStreamReader(self, self.audio_representation.id, self.audio_representation.mimeType)
             audio.open()
 
         if self.video_representation and self.audio_representation:
